/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.portal.iframe.el;

import java.util.regex.Pattern;

/**
 * Purpose of this class is to be able to use RegExp inside EL expressions in the JSP.
 * 
 * @author Claes Lundahl, vgrid=clalu4, Robert de Bésche, vgrid=robde1
 */
public final class RegExp {

    private RegExp() {

    }

    /**
     * The method evaluates whether a sequence of characters matches a given pattern.
     *
     * @param pattern the pattern String
     * @param str the {@link CharSequence}
     * @return <code>true</code> if it matches or <code>false</code> otherwise
     */
    public static boolean matches(String pattern, CharSequence str) {
        return Pattern.compile(pattern).matcher(str).matches();
    }

}
